@@ -56,7 +56,9 @@ metal = [
 
 jazz = [
 	SoloInstrument({'channel': 11}),
-	ChordInstrument({'channel': 1, 'max_velocity': 70, 'chance': 0.5}),
+	ChordInstrument({'channel': 4, 'max_velocity': 70, 'chance': 0.5}),
 	BassInstrument({'channel': 6}),
+	SlowStridePianist({'channel': 3}),
+	SimpleChordInstrument({'channel': 1}),
 	RockDrum({}),
 	]
